@@ -5,15 +5,17 @@
 #' @description
 #' Plot the posterior mean
 #'  of  model parameter \eqn{\theta} and
-#' and the latent function, i.e.
-#'  the Gaussian \eqn{ Gaussian(z|\mu,\sigma)}
-#'  with posterior mean estimates of \eqn{\mu,\sigma}.
+#'   the parameter of the latent function, i.e.
+#'  the normal distribution denoted by \eqn{ Gaussian(z|\mu,\sigma)}
+#'  with posterior mean estimates of its mean \eqn{\mu} and
+#'  standard deviation \eqn{\sigma}.
 #'
 
 #'
 #'
-#' @details  Our FROC model use a latent Gaussian random variable to determine hit rates.
-#' That is each hit rate is defined as follows;
+#' @details  Our FROC model
+#' use a latent Gaussian random variable to determine hit rates.
+#' That is, each hit rate is defined as follows;
 # \deqn{ p_5(z_1,...z_C; \mu, \sigma) = \int_{z_{5}}^{\infty} Gaussian(z|\mu,\sigma)dz}
 # \deqn{ p_4(z_1,...z_C; \mu, \sigma) = \int_{z_{4}}^{5} Gaussian(z|\mu,\sigma)dz}
 # \deqn{ p_3(z_1,...z_C; \mu, \sigma) = \int_{z_{3}}^{4} Gaussian(z|\mu,\sigma)dz}
@@ -32,12 +34,13 @@
 #'
 #'
 #'
-#'  For example, in the following data, the number of hit data with confidence level 5 \strong{41} which
-#'  is considered as an sample from the Binomial distribution of hit rate
+#'  For example, in the following data,
+#'  the number of hit data with the most
+#'   highest confidence level 5 is regarded as an sample from the Binomial distribution of hit rate
   # \eqn{p_5(z_1,...z_C; \mu, \sigma) = \int_{z_{5}}^{\infty} Gaussian(z|\mu,\sigma)dz}
 #'    \eqn{p_5(z_1,...z_C; \mu, \sigma) = \int_{z5}^{\infty} Gaussian(z|\mu,\sigma)dz}
 #'    with
-#'  Bernoulli trial number is NL=142.
+#'  Bernoulli trial number is \code{NL=142}.
 #'
 #'
 # LaTeX errors found:
@@ -62,8 +65,8 @@
 #'  And a reference distribution is  the standard Gaussian and do not confuse that
 #'  it is not the noise distribution, but only reference.
 #'
-#'  The noise distribution is \eqn{d \log \Phi} which determines the
-#'  False alarm rate in the similar manner and plotted by using a line of dots.
+#'  The noise distribution (denoted by \eqn{d \log \Phi})  determines the
+#'  False alarm rates in the similar manner and plotted by using a line of dots.
 #'  The author thinks the standard Gaussian is more comfortable to compare or confirm the shape of  \eqn{ Gaussian(z|\mu,\sigma)} and
 #'  thus, the author implement it in the \code{\link{draw_latent_signal_distribution}()}.
 #'
@@ -111,14 +114,14 @@
 #' @export
 #'
 #' @examples
-#' \donttest{
-#'#----------------------------------------------------------------------------------------
+#' \dontrun{
+#'#========================================================================================
 #'#   Shape of signal distribution strongly influences the value of AUC, so in the following
 #'#   the author shows how it affects the estimates of AUCs.
 #'#    We consider two data examples, one is a low AUC and the other is a high AUC.
 #'#   In the high AUC case, the Signal Gaussain will be low variance and
 #'#   in the low AUC case, the variance will desperse.  2019 August 4, 2019 Dec 17
-#'#----------------------------------------------------------------------------------------
+#'#========================================================================================
 #'
 #'
 #'#            ----- High AUC case --------
@@ -162,8 +165,8 @@
 #'
 #'
 #'      draw_latent_signal_distribution(fit,
-#'                    dark_theme = F,
-#'                    color = T,
+#'                    dark_theme  = FALSE,
+#'                    color = TRUE,
 #'                    density = 11
 #'                    )
 #'
@@ -171,9 +174,9 @@
 #'
 #' #' Without legends
 #' draw_latent_signal_distribution(fit,
-#'                                 dark_theme          = F,
-#'                                 color               = T,
-#'                                 mathmatical.symbols = F
+#'                                 dark_theme           = FALSE,
+#'                                 color               = TRUE,
+#'                                 mathmatical.symbols = FALSE
 #' )
 #'              # 2019 Sept. 5
 #'              # 2020 March 12
@@ -182,7 +185,6 @@
 #'
 #'
 #'
-
 #'}# dottest
 
 
@@ -651,7 +653,7 @@ cat("\n* thresholds:");cat(crayon::cyan(  signif(z,digits = dig)) ,sep = " < ")
 if (dark_theme ==TRUE)message("\n* ", crayon::green("Green")," curve indicates a signal distribution.")
 # message("\n* ", crayon::red("Red")," curve indicates a signal distribution.")
 
-#message(crayon::silver("\n* False alarm rate is not the area between two thresholds in the noise distribution. But the area is intuitively indicate the false alarm rate, thus the author color such areas."))
+#message(crayon::silver("\n* False alarm rate is not the area between two thresholds in the noise distribution. But the area is intuitively indicate the false alarm rate, thus the author color the areas."))
 
 
 # message("In the information geometrical view point, the two Gaussian distirbution is two points in the Poincare upper half plane. Thus we can also evaluate the observer performance by the distance. If the Signal distribution and the noise distribution is far, then we should consider that the observer performance is high, On the other hand, if this distane is small, then the observer performanse is low ability. This view is quite new. I also implement it   ")
@@ -830,15 +832,15 @@ message(" The Fisher metric  of the signal and the standard Gaussian disribution
 #' @export
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 
-#'#----------------------------------------------------------------------------------------
+#'#========================================================================================
 #'#   Shape of signal distribution strongly influences the value of AUC, so in the following
 #'#   the author shows how it affects the estimates of AUCs.
 #'#    We consider two data examples, one is a low AUC and the other is a high AUC.
 #'#   In the high AUC case, the Signal Gaussain will be low variance and
 #'#   in the low AUC case, the variance will desperse.  2019 August 4, 2019 Dec 17
-#'#----------------------------------------------------------------------------------------
+#'#========================================================================================
 #'
 #'#            ----- High AUC case --------
 #'
@@ -1249,7 +1251,7 @@ draw_latent_noise_distribution <- function( StanS4class,
   if (dark_theme ==TRUE)message("\n* ", crayon::green("Green")," curve indicates a signal distribution.")
   # message("\n* ", crayon::red("Red")," curve indicates a signal distribution.")
 
-  message(crayon::red("\n* False alarm rate is exactly the area between two thresholds in the differential logarithmic cumulative Gaussian distribution.The area intuitively indicates the false alarm rate, thus the author color such areas."))
+  message(crayon::red("\n* False alarm rate is exactly the area between two thresholds in the differential logarithmic cumulative Gaussian distribution.The area intuitively indicates the false alarm rate, thus the author color the areas."))
 
 
   # message("In the information geometrical view point, the two Gaussian distirbution is two points in the Poincare upper half plane. Thus we can also evaluate the observer performance by the distance. If the Signal distribution and the noise distribution is far, then we should consider that the observer performance is high, On the other hand, if this distane is small, then the observer performanse is low ability. This view is quite new. I also implement it   ")
