@@ -64,28 +64,28 @@
 #'
 #'
 #'
-#' \donttest{
+#' \dontrun{
 # ####1#### ####2#### ####3#### ####4#### ####5#### ####6#### ####7#### ####8#### ####9####
 #'
 #'
 #'
 #'#   The 1-st example: MRMC data
-#'#----------------------------------------------------------------------------------------
+#'#========================================================================================
 #'#                        1)  Fit a Model to MRMC Data
-#'#----------------------------------------------------------------------------------------
+#'#========================================================================================
 #'
 #'
 #'
 #'
-#'                fit <- fit_Bayesian_FROC( ite  = 1111,  dataList = ddd )
+#'                fit <- fit_Bayesian_FROC( ite  = 111,  dataList = ddd )
 #'
 #'
 #'
 #'
 #'
-#'#----------------------------------------------------------------------------------------
+#'#========================================================================================
 #'#  2)  Evaluate Posterior Predictive P value for the Goodness of Fit
-#'#----------------------------------------------------------------------------------------
+#'#========================================================================================
 #'
 #'
 #'
@@ -98,8 +98,8 @@
 #'
 #'
 #'
-#'#  If this quantity, namely a p value is greater,
-#'#  then we may say that our model is better.
+#'#  If this quantity, namely a p value, is greater,
+#'#  then we may say that our goodness of fit is better. (accept the null hypothesis)
 #'#  In the traditional procedure, if p-value is less than 0.05 or 0.01 then we reject
 #'#  the null hypothesis that our model fit to data well.
 #'
@@ -118,21 +118,21 @@
 #'
 #'
 #'#   The 2-nd example uses  data named d
-#'#----------------------------------------------------------------------------------------
+#'#========================================================================================
 #'#                  1)  Fit a Model to  Data
-#'#----------------------------------------------------------------------------------------
+#'#========================================================================================
 #'
 #'
 #'
 #'
-#'                        fitt <- fit_Bayesian_FROC( ite  = 1111,  dataList = d )
+#'                        fitt <- fit_Bayesian_FROC( ite  = 111,  dataList = d )
 #'
 #'
 #'
 #'
-#'#----------------------------------------------------------------------------------------
+#'#========================================================================================
 #'#  2)  Evaluate Posterior Predictive P value for the Goodness of Fit
-#'#----------------------------------------------------------------------------------------
+#'#========================================================================================
 #'
 #'
 #'
@@ -146,20 +146,20 @@
 #'
 #'
 #'
-#'#----------------------------------------------------------------------------------------
+#'#========================================================================================
 #'#                             PPP is problematic
-#'#----------------------------------------------------------------------------------------
+#'#========================================================================================
 #'
 #'# Consider the dataset:
 #'
 #'
-#' dat <- list(c=c(77,3,2,1),    #     Confidence level. Note that c is ignored.
+#' dat <- list(c=c(4,3,2,1),    #     Confidence level. Note that c is ignored.
 #'             h=c(77,97,32,31), #     Number of hits for each confidence level
-#'             f=c(1,14,74),  #     Number of false alarms for each confidence level
+#'             f=c(77,1,14,74),  #     Number of false alarms for each confidence level
 #'
 #'             NL=259,        #     Number of lesions
 #'             NI=57,         #     Number of images
-#'             C=3)           #     Number of confidence level#'
+#'             C=4)           #     Number of confidence level#'
 #'
 #'
 #'# Fit a model to the data
@@ -198,6 +198,7 @@
 #'
 #'
 #'
+#'
 #'}
 #'
 #'
@@ -300,13 +301,14 @@ ppp <- function(StanS4class,Colour=TRUE,dark_theme=TRUE,plot=TRUE ,summary = TRU
 #'
 #' Then, the function plots the following datasets \eqn{y_1^1,y_2^1,...,y_I^J}.
 #'
-#'\deqn{y_1^1,y_1^2,y_1^3,...,y_1^j,....,y_1^J \sim L ( . |\theta_1),}
-#'\deqn{y_2^1,y_2^2,y_2^3,...,y_2^j,....,y_2^J \sim L ( . |\theta_2),}
-#'\deqn{y_3^1,y_3^2,y_3^3,...,y_3^j,....,y_3^J \sim L ( .|\theta_3), }
+#'\deqn{ \chi(y_{1,1}|\theta_1), \chi(y_{1,2}|\theta_1), \chi(y_{1,3}|\theta_1),..., \chi(y_{1,j}|\theta_1),...., \chi(y_{1,J}|\theta_1),}
+#'\deqn{ \chi(y_{2,1}|\theta_2), \chi(y_{2,2}|\theta_2), \chi(y_{2,3}|\theta_2),..., \chi(y_{2,j}|\theta_2),...., \chi(y_{2,J}|\theta_2),}
+#'\deqn{ \chi(y_{3,1}|\theta_3), \chi(y_{3,2}|\theta_3), \chi(y_{3,3}|\theta_3),..., \chi(y_{3,j}|\theta_3),...., \chi(y_{3,J}|\theta_3),}
 #'\deqn{...,}
-#'\deqn{y_i^1,y_i^2,y_i^3,...,y_i^j,....,y_i^J \sim L ( . |\theta_i),}
+#'\deqn{ \chi(y_{i,1}|\theta_i), \chi(y_{i,2}|\theta_i), \chi(y_{i,3}|\theta_i),..., \chi(y_{i,j}|\theta_i),...., \chi(y_{I,J}|\theta_i),}
 #'\deqn{...,}
-#'\deqn{y_I^1,y_I^2,y_I^3,...,y_I^j,....,y_I^J \sim L ( . |\theta_I),}
+#'\deqn{ \chi(y_{I,1}|\theta_I), \chi(y_{I,2}|\theta_I), \chi(y_{I,3}|\theta_I),..., \chi(y_{I,j}|\theta_I),...., \chi(y_{I,J}|\theta_I).}
+#'
 #'
 #'where \eqn{L ( . |\theta_i)} is a likelihood at parameter \eqn{\theta_i}.
 #'
@@ -330,12 +332,12 @@ ppp <- function(StanS4class,Colour=TRUE,dark_theme=TRUE,plot=TRUE ,summary = TRU
 #'
 #' \deqn{ \int \int I( \chi(y|\theta) > \chi(y_0|\theta) )   f(y|\theta) \pi(\theta|y_0) d \theta d y  }
 #' \deqn{ \approx \int \sum_i I( \chi(y|\theta_i) > \chi(y_0|\theta_i) )   f(y|\theta_i) d y   }
-#' \deqn{ \approx \sum_{j=1}^J \sum_{i=1}^I I( \chi(y_i^j|\theta_i) > \chi(y_0|\theta_i) )     }
+#' \deqn{ \approx \sum_{j=1}^J \sum_{i=1}^I I( \chi(y_{i,j}|\theta_i) > \chi(y_0|\theta_i) )     }
 
 #'
 #'
 #'
-#'   When we plot these replicated data \eqn{y_i^j}, we use the \code{jitter()} which adds a small amount of noise to \strong{avoid overlapping points}.
+#'   When we plot these synthesized data-sets \eqn{y_{i,j}}, we use the \code{jitter()} which adds a small amount of noise to \strong{avoid overlapping points}.
 #' For example, \code{jitter(c(1,1,1,1))} returns  values: \code{1.0161940 1.0175678 0.9862400 0.9986126}, which is changed
 #' from \code{1,1,1,1} to be not exactly 1 by adding tiny errors to avoid overlapping. I love you. 2019 August 19
 #' Nowadays, I cannot remove my self from some notion, such as honesty, or pain, or,.. maybe these thing is no longer with myself.
@@ -374,31 +376,33 @@ ppp <- function(StanS4class,Colour=TRUE,dark_theme=TRUE,plot=TRUE ,summary = TRU
 #' @examples
 #'
 #'
-#' \donttest{
+#' \dontrun{
 #'
-#'#----------------------------------------------------------------------------------------
-#'#            1) Create a fitted model object with data named only one word d
-#'#----------------------------------------------------------------------------------------
+#'#========================================================================================
+#'#            1) Create a fitted model object with data named  "d"
+#'#========================================================================================
 #'
 #'
 #'
-#'                            fit <- fit_Bayesian_FROC(d )
+#' fit <- fit_Bayesian_FROC( dataList = d,
+#'                               ite  = 222 # to restrict running time, but it is too small
+#'                            )
 #'
 #'
 #'
-#'#----------------------------------------------------------------------------------------
+#'#========================================================================================
 #'#            2) Calculate p value and meta data
-#'#----------------------------------------------------------------------------------------
+#'#========================================================================================
 #'
 #'
 #'
-#'                               ppp <- ppp(fit)
+#'                               ppp <- ppp_srsc(fit)
 #'
 #'
 #'
-#'#----------------------------------------------------------------------------------------
+#'#========================================================================================
 #'#            3) Extract a p value
-#'#----------------------------------------------------------------------------------------
+#'#========================================================================================
 #'
 #'
 #'
@@ -408,6 +412,7 @@ ppp <- function(StanS4class,Colour=TRUE,dark_theme=TRUE,plot=TRUE ,summary = TRU
 #'
 #'# Revised 2019 August 19
 #'# Revised 2019 Nov 27
+#'
 
 #'}
 #'
@@ -485,7 +490,7 @@ ppp_srsc <-function( StanS4class,
 
 
   # process indicator ---------
-  message("\n* Process for calculation \n")#Processssssssssssssssssssssssssssssssssssssssssssssssssssss
+  message("\n* Process for calculation of the posterior predictive p-value. \n")#Processssssssssssssssssssssssssssssssssssssssssssssssssssss
   cat(0," -> ")#Adjust#Processssssssssssssssssssssssssssssssssssssssssssssssssssss
   sss <-0 #dummy for process indicator#ProcesssssssssProcessssssssssssssssssssssssssssssssssssssssssssssssssssss
   Divisor <-100#ProcesssssssssProcessssssssssssssssssssssssssssssssssssssssssssssssssssss
@@ -801,22 +806,22 @@ for (mcmc in 1:MCMC) {
 #'
 #'
 #'
-#' \donttest{
-#'#----------------------------------------------------------------------------------------
+#' \dontrun{
+#'#========================================================================================
 #'#  1)  Fit a Model to MRMC Data
-#'#----------------------------------------------------------------------------------------
+#'#========================================================================================
 #'
-#'   fit <- fit_Bayesian_FROC( ite  = 1111,  dataList = ddd )
+#'   fit <- fit_Bayesian_FROC( ite  = 111,  dataList = ddd )
 #'
-#'#----------------------------------------------------------------------------------------
+#'#========================================================================================
 #'#  1)  Evaluate Posterior Predictive P value for the Goodness of Fit
-#'#----------------------------------------------------------------------------------------
+#'#========================================================================================
 #'
 #'      ppp_MRMC(fit)
 #'
 #'#  If this quantity is greater, then we may say that our model is better.
 #'
-#'#  I made this ppp at 2019 August 25. Tinko Tinko Tinko oppai ga ippai!! hentai banzai!
+#'#  I made this ppp at 2019 August 25.
 #'
 #'
 #'}#'
